<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/


class Activity_Model_DbTable_Files extends Engine_Db_Table {

  protected $_rowClass = 'Activity_Model_File';
}
