<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class='settings'>
  <?php echo $this->form->render($this); ?>
</div>
<script type="application/javascript">
  function setModuleName(value){
    document.getElementById('module').value = value;;  
  }
  if(document.getElementById('module'))
    document.getElementById('module').value = document.getElementById('filtertype').options[document.getElementById('filtertype').selectedIndex].text;
</script>
