<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
return array (
  ":)" => "smile.png",
  ":(" => "sad.png",
  ":D" => "smile-big.png",
  ";)" => "wink.png",
  ":-O" => "shock.png",
  ":P" => "tongue.png",
  ":-X" => "shut-mouth.png",
  ":|" => "neutral.png",
  "(6)" => "devil.png",
  "(A)" => "angel.png",
  "(L)" => "love.png",
  "(U)" => "love-over.png",
  "(H)" => "glasses-cool.png",
  ":@" => "angry.png",
  ":$" => "embarrassed.png",
  ":S" => "confused.png",
  ":'(" => "crying.png",
  "I-)" => "sleepy.png",
  "^:)^" => "worship.png",
  ":-W" => "wait.png",
  "=;" => "bye.png",
  "[-X" => "shame.png",
  "(@)" => "cat.png",
  "(&)" => "dog.png",
  "(S)" => "moon.png",
  "(*)" => "star.png",
  "(I)" => "lamp.png",
  "(C)" => "coffee.png",
  "(T)" => "phone.png",
  "({)" => "hug-left.png",
  "(})" => "hug-right.png",
  "(Y)" => "good.png",
  "(N)" => "bad.png",
  ":[" => "vampire.png",
  "(nah)" => "goat.png",
  "(#)" => "sun.png",
  "(R)" => "rainbow.png",
  "(~)" => "film.png",
  "(8)" => "musical-note.png",
  "(E)" => "mail.png",
  "(F)" => "rose.png",
  "(W)" => "rose-dead.png",
  "(O)" => "clock.png",
  "(K)" => "kiss.png",
  "(G)" => "present.png",
  "(^)" => "cake.png",
  "(P)" => "camera.png",
  ":-#" => "quiet.png",
  "8o|" => "teeth.png",
  "8-|" => "glasses-nerdy.png",
  "^o)" => "sarcastic.png",
  ":-*" => "secret.png",
  "+o(" => "sick.png",
  "(sn)" => "snail.png",
  "(tu)" => "turtle.png",
  "(B)" => "beer.png",
  "(D)" => "drink.png",
  "(Z)" => "boy.png",
  "(X)" => "girl.png",
  "(pl)" => "plate.png",
  "(||)" => "bowl.png",
  "(pi)" => "pizza.png",
  "(so)" => "soccerball.png",
  "(au)" => "car.png",
  "(ap)" => "airplane.png",
  "(um)" => "umbrella.png",
  "(h5)" => "highfive.png",
  "(co)" => "computer.png",
  "(bah)" => "sheep.png",
  ":^)" => "dont-know.png",
  "*-)" => "thinking.png",
  "(li)" => "thunder.png",
  "(ip)" => "island.png",
  "(mp)" => "mobile.png",
  "(brb)" => "brb.png",
  "(st)" => "rain.png",
  ":o)" => "party.png",
  "8-)" => "eyeroll.png",
  "|-)" => "yawn.png"
);
