ALTER TABLE `engine4_activity_notificationtypes` CHANGE `type` `type` VARCHAR(128) NOT NULL;
ALTER TABLE `engine4_activity_actions` CHANGE `type` `type` VARCHAR(128) NOT NULL;
ALTER TABLE `engine4_activity_actiontypes` CHANGE `type` `type` VARCHAR(128) NOT NULL;
ALTER TABLE `engine4_activity_notifications` CHANGE `type` `type` VARCHAR(128) NOT NULL;
