<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="comment_emotion_container activity_emoji_container activity_feeling_emoji_container _feeling_emoji_content notclose">
  <div class="activity_feeling_emoji_container_inner">
    <div class="activity_emoji_holder">
      <div class="loading_container empty_cnt" style="height:100%;"></div>
    </div>
  </div>
</div>