.tooltipster-default {
	background-color:var(--theme-list-background-color);
	border-radius:3px;
  -webkit-border-radius:2px;
	filter:drop-shadow(0 2px 4px rgba(34,36,38,0.15));
	-webkit-filter:drop-shadow(0 2px 4px rgba(34,36,38,0.15));
	border-radius:0.625rem;
	overflow:hidden;
}
.tooltipster-default .tooltipster-content {
	padding:10px;
	font-size:var(--theme-font-size); 
	overflow:hidden;
}
.tooltipster-icon {
	cursor:help;
	margin-left:4px;
}
.tooltipster-base {
	padding:0;
	font-size:0;
	line-height:0;
	position:absolute;
	left:0;
	top:0;
	z-index:9999999;
	pointer-events:none;
	width:auto;
	overflow:visible;
}
.tooltipster-arrow {
	display:none;
}
.tooltipster-fade {
	opacity:0;
	-webkit-transition-property:opacity;
	-moz-transition-property:opacity;
	-o-transition-property:opacity;
	-ms-transition-property:opacity;
	transition-property:opacity;
}
.tooltipster-fade-show {
	opacity:1;
}
/* CSS transition for when contenting is changing in a tooltip that is still open. The only properties that will NOT transition are:width, height, top, and left */
.tooltipster-content-changing {
	opacity:0.5;
	-webkit-transform:scale(1.1, 1.1);
	-moz-transform:scale(1.1, 1.1);
	-o-transform:scale(1.1, 1.1);
	-ms-transform:scale(1.1, 1.1);
	transform:scale(1.1, 1.1);
}
/*ToolTip Content*/
.info_tooltip{
	width:350px;
	line-height: 1.5;
}
.info_tooltip_cover{
	border-radius:10px;
	height:150px;
	overflow:hidden;
	position:relative;
	margin-bottom:0.9375rem;
	width:100%;
}
.info_tooltip_cover > img{
	object-fit:cover;
	height:100%;
	width:100%;
}
.info_tooltip_content{
	position:relative;
	display:flex;
	flex-wrap:wrap;
	gap:0.9375rem
}
.info_tooltip_cover + .info_tooltip_content{
	padding:0 15px 10px;
}
.info_tooltip_photo{
	background-color:var(--theme-list-background-color);
	border-radius:50%;
	border-width:0.0625rem;
	height:7.5rem;
	padding:0.125rem;
	overflow:hidden;
	position:relative;
	width:7.5rem;
}
.info_tooltip_cover + .info_tooltip_content .info_tooltip_photo{
	margin-top:-50px;
}
.info_tooltip_photo span{
	border-radius:50%;
	height:100%;
	object-fit:cover;
	width:100%;
}
.info_tooltip_info{
	flex:1;
}
.info_tooltip_info_title{
	font-weight:var(--theme-font-weight-bold);
	font-size:1.125rem;;
	margin-top:20px;
}
.info_tooltip_cover + .info_tooltip_content .info_tooltip_info_title{
	margin-top:0;
}
.info_tooltip_info_stats{
	margin-top:3px;
	display:block;
}
.info_tooltip_stats{
	margin-top:3px;
	clear:both;
	display:flex;
	flex-wrap:wrap;
	gap:0.625rem 0;
	align-items:center;
	width:100%;
}
.info_tooltip_stats > span{
	display:flex;
	gap:0.1875rem;
}
.info_tooltip_stats > span + span:before{
	content:"•";
	margin: 0 0.3125rem;
}
.info_tooltip_stats > span i{
	width:16px;
	text-align:center !important;
}
.info_tooltip_buttons{
	/* border-top-width: 1px; */
	padding-top: 10px;
	width:100%;
	display:flex;
	justify-content:flex-end;
	gap:0.625rem;
}
.info_tooltip_buttons a{
	padding: 0.375rem 0.625rem;
}
