UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-refresh' WHERE `filtertype` = 'all';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-sitemap' WHERE `filtertype` = 'my_networks';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-users' WHERE `filtertype` = 'my_friends';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-blog-text' WHERE `filtertype` = 'posts';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-floppy-disks' WHERE `filtertype` = 'saved_feeds';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-shopping-cart' WHERE `filtertype` = 'post_self_buysell';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-time-past' WHERE `filtertype` = 'scheduled_post';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-share' WHERE `filtertype` = 'share';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-picture' WHERE `filtertype` = 'album';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-video-camera-alt' WHERE `filtertype` = 'video';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-music-alt' WHERE `filtertype` = 'music';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-document' WHERE `filtertype` = 'post_self_file';
UPDATE `engine4_activity_filterlists` SET `icon`= 'fi fi-rr-blog-pencil' WHERE `filtertype` = 'blog';