<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
 
class Activity_Model_Emoji extends Core_Model_Item_Abstract
{
  protected $_searchTriggers = false;
}