<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php
if (!empty($this->commentCount)) {
  $commentcount = $this->translate(array('%s comment', '%s comments', $this->commentCount), $this->locale()->toNumber($this->commentCount));
?>
<?php echo $commentcount; ?>
<?php } die; ?>