--
-- Dumping data for table `engine4_core_menuitems`
--

 INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES
('core_admin_main_settings_emoticons', 'activity', 'Emoticons', '', '{"route":"admin_default","module":"activity","controller":"settings","action":"manage-emoticons"}', 'core_admin_main_settings', '', 4);