<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Activity_Model_DbTable_Hashtags extends Engine_Db_Table {

  public function getAllHashtags($action_id) {
    
    $select = $this->select()
                  ->from($this->info('name'))
                  ->where('action_id =?', $action_id);
    return $this->fetchAll($select);
  }
}
