<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Activity_Model_DbTable_Comments extends Core_Model_DbTable_Comments
{
  protected $_rowClass = 'Activity_Model_Comment';

  public function getResourceType()
  {
    return 'activity_action';
  }
}
