<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<span>-</span>
<span class="timestamp" title="<?php echo $this->lastEditedDate ?>">
	<?php echo $this->translate('edited') ?>
</span>