<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Activity_Bootstrap extends Engine_Application_Bootstrap_Abstract
{

  public function __construct($application)
  {

    parent::__construct($application);

    $this->initViewHelperPath();

    $front = Zend_Controller_Front::getInstance();
    $front->registerPlugin(new Activity_Plugin_Core);

    //Emotions Load
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $script = "var chatEmotions = " . Engine_Api::_()->activity()->getEmoticons('', '', true) . ";";
    $view->headScript()->appendScript($script);
  }
}
