<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<script type="text/javascript">
  parent.document.getElementById('activity-item-<?php echo $this->action_id ?>').destroy();
  setTimeout(function () {
    parent.Smoothbox.close();
  }, <?php echo ($this->smoothboxClose === true ? 1000 : $this->smoothboxClose); ?>);
</script>


<div class="global_form_popup_message">
  <?php echo $this->message ?>
</div>