INSERT IGNORE INTO `engine4_core_settings` (`name`, `value`) VALUES
('activity.composer.options.0', 'emoticons'),
('activity.composer.options.1', 'userTags'),
('activity.composer.options.2', 'hashtags'),
('activity.view.privacy.0', 'everyone'),
('activity.view.privacy.1', 'networks'),
('activity.view.privacy.2', 'friends'),
('activity.view.privacy.3', 'onlyme'),
('activity.network.privacy', 2);
