<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Activity_Model_Buysell extends Core_Model_Item_Abstract {

  protected $_searchTriggers = false;
  public function getMediaType(){
    return 'post';
  }
  
  public function getHref(){
    $action = Engine_Api::_()->getItem('activity_action',$this->action_id);
    if(!$action)
      return 'javascript:;';
    return  $action->getHref();
  }
}
