<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class='settings'>
  <?php echo $this->form->render($this); ?>
</div>
<script type="text/javascript">
  function changemodule(modulename) {
    var type = '<?php echo $this->type ?>';
    var feeling_id = '<?php echo $this->feeling_id ?>';
    window.location.href="<?php echo $this->url(array('module'=>'activity','controller'=>'feeling', 'action'=>'add-feelingicon'),'admin_default',true)?>/module_name/"+modulename + "/type/" +type+"/feeling_id/"+feeling_id;
  }
</script>
