<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Activity_Model_DbTable_Emojis extends Engine_Db_Table
{
  protected $_rowClass = 'Activity_Model_Emoji';

  public function getPaginator($params = array())
  {
    return Zend_Paginator::factory($this->getEmojis($params));
  }

  public function getEmojis($params = array())
  {
    $select = $this->select()
      ->where('emoji_id <> ?', 3)
      ->order('order ASC')
      ;
    if (!empty($params['fetchAll'])) {
      return $this->fetchAll($select);
    }
    return $select;
  }
}